"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorSchemeStore = void 0;
const react_native_1 = require("react-native");
class ColorSchemeStore {
    constructor(colorSchemeSystem) {
        this.colorSchemeListeners = new Set();
        this.subscribeColorScheme = (listener) => {
            this.colorSchemeListeners.add(listener);
            return () => this.colorSchemeListeners.delete(listener);
        };
        this.getColorScheme = () => {
            return this.colorScheme;
        };
        this.setColorScheme = (colorSchemeSystem) => {
            this.colorSchemeSystem = colorSchemeSystem;
            this.colorScheme =
                colorSchemeSystem === "system"
                    ? react_native_1.Appearance.getColorScheme() || "light"
                    : colorSchemeSystem;
            this.notifyMedia(["colorScheme"]);
            this.notifyColorScheme();
        };
        this.toggleColorScheme = () => {
            const currentColor = this.colorSchemeSystem === "system"
                ? react_native_1.Appearance.getColorScheme() || "light"
                : this.colorScheme;
            this.colorScheme = currentColor === "light" ? "dark" : "light";
            this.colorSchemeSystem = currentColor;
            this.notifyMedia(["colorScheme"]);
            this.notifyColorScheme();
        };
        if (colorSchemeSystem === "system" || colorSchemeSystem === undefined) {
            this.colorScheme = react_native_1.Appearance.getColorScheme() || "light";
            this.colorSchemeSystem = "system";
        }
        else {
            this.colorScheme = colorSchemeSystem;
            this.colorSchemeSystem = colorSchemeSystem;
        }
        if (react_native_1.Platform.OS === "web") {
            if (localStorage.theme === "dark" ||
                (!("theme" in localStorage) &&
                    window.matchMedia("(prefers-color-scheme: dark)").matches)) {
                document.documentElement.classList.add("dark");
            }
            else {
                document.documentElement.classList.remove("dark");
            }
            this.subscribeColorScheme(() => {
                if (this.colorSchemeSystem === "system") {
                    localStorage.removeItem("theme");
                }
                else {
                    localStorage.theme = this.colorSchemeSystem;
                }
            });
        }
    }
    notifyColorScheme() {
        for (const l of this.colorSchemeListeners)
            l();
    }
}
exports.ColorSchemeStore = ColorSchemeStore;
