"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.styled = void 0;
const react_1 = require("react");
const use_interaction_1 = require("./use-interaction");
const with_styled_children_1 = require("./with-styled-children");
const with_styled_props_1 = require("./with-styled-props");
const use_tailwind_1 = require("./use-tailwind");
const with_class_names_1 = require("./with-class-names");
const style_sheet_store_1 = require("./style-sheet-store");
const component_context_1 = require("./component-context");
/**
 * Actual implementation
 */
function styled(Component, styledBaseClassNameOrOptions, maybeOptions = {}) {
    const { props: propsToTransform, spreadProps, classProps, } = typeof styledBaseClassNameOrOptions === "object"
        ? styledBaseClassNameOrOptions
        : maybeOptions;
    const baseClassName = typeof styledBaseClassNameOrOptions === "string"
        ? styledBaseClassNameOrOptions
        : maybeOptions === null || maybeOptions === void 0 ? void 0 : maybeOptions.baseClassName;
    function Styled({ className: propClassName, tw: twClassName, baseTw, style: styleProp, children: componentChildren, ...componentProps }, ref) {
        const store = (0, react_1.useContext)(style_sheet_store_1.StoreContext);
        const { className, allClasses, isComponent, isParent } = (0, with_class_names_1.withClassNames)({
            baseClassName,
            propClassName,
            twClassName,
            baseTw,
            componentProps,
            propsToTransform,
            spreadProps,
            classProps,
        });
        const { hover, focus, active, ...handlers } = (0, use_interaction_1.useInteraction)({
            className: allClasses,
            isComponent,
            isParent,
            store,
            ...componentProps,
        });
        const { additionalStyles, ...styledProps } = (0, with_styled_props_1.withStyledProps)({
            preprocessed: store.preprocessed,
            propsToTransform,
            componentProps,
            classProps,
        });
        const style = (0, use_tailwind_1.useTailwind)(className, {
            hover,
            focus,
            active,
        }, styleProp, additionalStyles);
        const children = (0, with_styled_children_1.withStyledChildren)({
            store,
            componentChildren,
            stylesArray: style,
            parentHover: hover,
            parentFocus: focus,
            parentActive: active,
        });
        const element = (0, react_1.createElement)(Component, {
            ...handlers,
            ...styledProps,
            style: style.length > 0 ? style : undefined,
            children,
            ref,
        });
        return !isComponent
            ? element
            : (0, react_1.createElement)(component_context_1.ComponentContext.Provider, {
                children: element,
                value: { hover, focus, active },
            });
    }
    if (typeof Component !== "string") {
        Styled.displayName = `TailwindCssReactNative.${Component.displayName || Component.name || "NoName"}`;
    }
    return (0, react_1.forwardRef)(Styled);
}
exports.styled = styled;
