"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTailwind = void 0;
const react_1 = require("react");
const style_sheet_store_1 = require("./style-sheet-store");
const with_selector_1 = require("use-sync-external-store/shim/with-selector");
function useTailwind(classNames, options = {}, inlineStyles, additionalStyles = []) {
    const store = (0, react_1.useContext)(style_sheet_store_1.StoreContext);
    // useSyncExternalStore doesn't require but stable selector but
    // useSyncExternalStoreWithSelector does :(
    const selector = (0, react_1.useMemo)(() => store.createSelector(classNames, options), [
        store,
        classNames,
        options.hover,
        options.focus,
        options.active,
        options.componentHover,
        options.componentFocus,
        options.componentActive,
    ]);
    const styles = (0, with_selector_1.useSyncExternalStoreWithSelector)(store.subscribe, store.getSnapshot, undefined, selector);
    return (0, react_1.useMemo)(() => {
        const stylesArray = [
            ...styles,
            ...additionalStyles,
            inlineStyles,
        ].filter(Boolean);
        stylesArray.childStyles = styles.childStyles;
        return stylesArray;
    }, [styles, inlineStyles, additionalStyles]);
}
exports.useTailwind = useTailwind;
